==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ecs/kotlin/ClusterCapacityProviders.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ecs.kotlin

import com.pulumi.aws.ecs.kotlin.outputs.ClusterCapacityProvidersDefaultCapacityProviderStrategy
import com.pulumi.aws.ecs.kotlin.outputs.ClusterCapacityProvidersDefaultCapacityProviderStrategy.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [ClusterCapacityProviders].
 */
@PulumiTagMarker
public class ClusterCapacityProvidersResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ClusterCapacityProvidersArgs = ClusterCapacityProvidersArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ClusterCapacityProvidersArgsBuilder.() -> Unit) {
        val builder = ClusterCapacityProvidersArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): ClusterCapacityProviders {
        val builtJavaResource = com.pulumi.aws.ecs.ClusterCapacityProviders(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return ClusterCapacityProviders(builtJavaResource)
    }
}

/**
 * Manages the capacity providers of an ECS Cluster.
 * More information about capacity providers can be found in the [ECS User Guide](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-capacity-providers.html).
 * ## Example Usage
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.ecs.Cluster;
 * import com.pulumi.aws.ecs.ClusterCapacityProviders;
 * import com.pulumi.aws.ecs.ClusterCapacityProvidersArgs;
 * import com.pulumi.aws.ecs.inputs.ClusterCapacityProvidersDefaultCapacityProviderStrategyArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var exampleCluster = new Cluster("exampleCluster");
 *         var exampleClusterCapacityProviders = new ClusterCapacityProviders("exampleClusterCapacityProviders", ClusterCapacityProvidersArgs.builder()
 *             .clusterName(exampleCluster.name())
 *             .capacityProviders("FARGATE")
 *             .defaultCapacityProviderStrategies(ClusterCapacityProvidersDefaultCapacityProviderStrategyArgs.builder()
 *                 .base(1)
 *                 .weight(100)
 *                 .capacityProvider("FARGATE")
 *                 .build())
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * Using `pulumi import`, import ECS cluster capacity providers using the `cluster_name` attribute. For example:
 * ```sh
 *  $ pulumi import aws:ecs/clusterCapacityProviders:ClusterCapacityProviders example my-cluster
 * ```
 *
 */
public class ClusterCapacityProviders internal constructor(
    override val javaResource: com.pulumi.aws.ecs.ClusterCapacityProviders,
) : KotlinCustomResource(javaResource, ClusterCapacityProvidersMapper) {
    /**
     * Set of names of one or more capacity providers to associate with the cluster. Valid values also include `FARGATE` and `FARGATE_SPOT`.
     */
    public val capacityProviders: Output<List<String>>?
        get() = javaResource.capacityProviders().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * Name of the ECS cluster to manage capacity providers for.
     */
    public val clusterName: Output<String>
        get() = javaResource.clusterName().applyValue({ args0 -> args0 })

    /**
     * Set of capacity provider strategies to use by default for the cluster. Detailed below.
     */
    public val defaultCapacityProviderStrategies:
        Output<List<ClusterCapacityProvidersDefaultCapacityProviderStrategy>>?
        get() = javaResource.defaultCapacityProviderStrategies().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.let({ args0 ->
                        toKotlin(args0)
                    })
                })
            }).orElse(null)
        })
}

public object ClusterCapacityProvidersMapper : ResourceMapper<ClusterCapacityProviders> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.aws.ecs.ClusterCapacityProviders::class == javaResource::class

    override fun map(javaResource: Resource): ClusterCapacityProviders =
        ClusterCapacityProviders(javaResource as com.pulumi.aws.ecs.ClusterCapacityProviders)
}

/**
 * @see [ClusterCapacityProviders].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ClusterCapacityProviders].
 */
public suspend fun clusterCapacityProviders(
    name: String,
    block: suspend ClusterCapacityProvidersResourceBuilder.() -> Unit,
): ClusterCapacityProviders {
    val builder = ClusterCapacityProvidersResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ClusterCapacityProviders].
 * @param name The _unique_ name of the resulting resource.
 */
public fun clusterCapacityProviders(name: String): ClusterCapacityProviders {
    val builder = ClusterCapacityProvidersResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ecs/kotlin/ClusterCapacityProviders.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ecs.kotlin

import com.pulumi.aws.ecs.kotlin.outputs.ClusterCapacityProvidersDefaultCapacityProviderStrategy
import com.pulumi.aws.ecs.kotlin.outputs.ClusterCapacityProvidersDefaultCapacityProviderStrategy.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [ClusterCapacityProviders].
 */
@PulumiTagMarker
public class ClusterCapacityProvidersResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ClusterCapacityProvidersArgs = ClusterCapacityProvidersArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ClusterCapacityProvidersArgsBuilder.() -> Unit) {
        val builder = ClusterCapacityProvidersArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): ClusterCapacityProviders {
        val builtJavaResource = com.pulumi.aws.ecs.ClusterCapacityProviders(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return ClusterCapacityProviders(builtJavaResource)
    }
}

/**
 * Manages the capacity providers of an ECS Cluster.
 * More information about capacity providers can be found in the [ECS User Guide](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-capacity-providers.html).
 * ## Example Usage
 * <!--Start PulumiCodeChooser -->
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws from "@pulumi/aws";
 * const example = new aws.ecs.Cluster("example", {name: "my-cluster"});
 * const exampleClusterCapacityProviders = new aws.ecs.ClusterCapacityProviders("example", {
 *     clusterName: example.name,
 *     capacityProviders: ["FARGATE"],
 *     defaultCapacityProviderStrategies: [{
 *         base: 1,
 *         weight: 100,
 *         capacityProvider: "FARGATE",
 *     }],
 * });
 * ```
 * ```python
 * import pulumi
 * import pulumi_aws as aws
 * example = aws.ecs.Cluster("example", name="my-cluster")
 * example_cluster_capacity_providers = aws.ecs.ClusterCapacityProviders("example",
 *     cluster_name=example.name,
 *     capacity_providers=["FARGATE"],
 *     default_capacity_provider_strategies=[{
 *         "base": 1,
 *         "weight": 100,
 *         "capacity_provider": "FARGATE",
 *     }])
 * ```
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using Aws = Pulumi.Aws;
 * return await Deployment.RunAsync(() =>
 * {
 *     var example = new Aws.Ecs.Cluster("example", new()
 *     {
 *         Name = "my-cluster",
 *     });
 *     var exampleClusterCapacityProviders = new Aws.Ecs.ClusterCapacityProviders("example", new()
 *     {
 *         ClusterName = example.Name,
 *         CapacityProviders = new[]
 *         {
 *             "FARGATE",
 *         },
 *         DefaultCapacityProviderStrategies = new[]
 *         {
 *             new Aws.Ecs.Inputs.ClusterCapacityProvidersDefaultCapacityProviderStrategyArgs
 *             {
 *                 Base = 1,
 *                 Weight = 100,
 *                 CapacityProvider = "FARGATE",
 *             },
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-aws/sdk/v6/go/aws/ecs"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		example, err := ecs.NewCluster(ctx, "example", &ecs.ClusterArgs{
 * 			Name: pulumi.String("my-cluster"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		_, err = ecs.NewClusterCapacityProviders(ctx, "example", &ecs.ClusterCapacityProvidersArgs{
 * 			ClusterName: example.Name,
 * 			CapacityProviders: pulumi.StringArray{
 * 				pulumi.String("FARGATE"),
 * 			},
 * 			DefaultCapacityProviderStrategies: ecs.ClusterCapacityProvidersDefaultCapacityProviderStrategyArray{
 * 				&ecs.ClusterCapacityProvidersDefaultCapacityProviderStrategyArgs{
 * 					Base:             pulumi.Int(1),
 * 					Weight:           pulumi.Int(100),
 * 					CapacityProvider: pulumi.String("FARGATE"),
 * 				},
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.aws.ecs.Cluster;
 * import com.pulumi.aws.ecs.ClusterArgs;
 * import com.pulumi.aws.ecs.ClusterCapacityProviders;
 * import com.pulumi.aws.ecs.ClusterCapacityProvidersArgs;
 * import com.pulumi.aws.ecs.inputs.ClusterCapacityProvidersDefaultCapacityProviderStrategyArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var example = new Cluster("example", ClusterArgs.builder()
 *             .name("my-cluster")
 *             .build());
 *         var exampleClusterCapacityProviders = new ClusterCapacityProviders("exampleClusterCapacityProviders", ClusterCapacityProvidersArgs.builder()
 *             .clusterName(example.name())
 *             .capacityProviders("FARGATE")
 *             .defaultCapacityProviderStrategies(ClusterCapacityProvidersDefaultCapacityProviderStrategyArgs.builder()
 *                 .base(1)
 *                 .weight(100)
 *                 .capacityProvider("FARGATE")
 *                 .build())
 *             .build());
 *     }
 * }
 * ```
 * ```yaml
 * resources:
 *   example:
 *     type: aws:ecs:Cluster
 *     properties:
 *       name: my-cluster
 *   exampleClusterCapacityProviders:
 *     type: aws:ecs:ClusterCapacityProviders
 *     name: example
 *     properties:
 *       clusterName: ${example.name}
 *       capacityProviders:
 *         - FARGATE
 *       defaultCapacityProviderStrategies:
 *         - base: 1
 *           weight: 100
 *           capacityProvider: FARGATE
 * ```
 * <!--End PulumiCodeChooser -->
 * ## Import
 * Using `pulumi import`, import ECS cluster capacity providers using the `cluster_name` attribute. For example:
 * ```sh
 * $ pulumi import aws:ecs/clusterCapacityProviders:ClusterCapacityProviders example my-cluster
 * ```
 */
public class ClusterCapacityProviders internal constructor(
    override val javaResource: com.pulumi.aws.ecs.ClusterCapacityProviders,
) : KotlinCustomResource(javaResource, ClusterCapacityProvidersMapper) {
    /**
     * Set of names of one or more capacity providers to associate with the cluster. Valid values also include `FARGATE` and `FARGATE_SPOT`.
     */
    public val capacityProviders: Output<List<String>>?
        get() = javaResource.capacityProviders().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 -> args0 })
            }).orElse(null)
        })

    /**
     * Name of the ECS cluster to manage capacity providers for.
     */
    public val clusterName: Output<String>
        get() = javaResource.clusterName().applyValue({ args0 -> args0 })

    /**
     * Set of capacity provider strategies to use by default for the cluster. Detailed below.
     */
    public val defaultCapacityProviderStrategies:
        Output<List<ClusterCapacityProvidersDefaultCapacityProviderStrategy>>?
        get() = javaResource.defaultCapacityProviderStrategies().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.let({ args0 ->
                        toKotlin(args0)
                    })
                })
            }).orElse(null)
        })
}

public object ClusterCapacityProvidersMapper : ResourceMapper<ClusterCapacityProviders> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.aws.ecs.ClusterCapacityProviders::class == javaResource::class

    override fun map(javaResource: Resource): ClusterCapacityProviders =
        ClusterCapacityProviders(javaResource as com.pulumi.aws.ecs.ClusterCapacityProviders)
}

/**
 * @see [ClusterCapacityProviders].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ClusterCapacityProviders].
 */
public suspend fun clusterCapacityProviders(
    name: String,
    block: suspend ClusterCapacityProvidersResourceBuilder.() -> Unit,
): ClusterCapacityProviders {
    val builder = ClusterCapacityProvidersResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ClusterCapacityProviders].
 * @param name The _unique_ name of the resulting resource.
 */
public fun clusterCapacityProviders(name: String): ClusterCapacityProviders {
    val builder = ClusterCapacityProvidersResourceBuilder()
    builder.name(name)
    return builder.build()
}
